# JSON Schema

## QueueState
```json
{
  "$schema": "http://json-schema.org/draft-07/schema#",
  "$id": "https://forge.etsi.org/rep/emtel/ts-103-479/json-schema/",
  "title": "QueueState",
  "description": "QueueState event notification",
  "type": "object",
  "properties": {
    "QueueStateEventUri": {
      "description": "The SIP URI of the queue",
      "type": "string"
    },
    "QueueStateEventQueueLength": {
      "description": "Indicating current number of calls on the queue",
      "type": "integer",
      "minimum": 0
    },
    "QueueStateEventMaxLength": {
      "description": "Integer indicating maximum length of queue",
      "type": "integer",
      "minimum": 0
    },
    "QueueStateValuesCode": {
      "description": "Enumeration of current queue state (e.g., Active/Inactive/Disabled)",
      "type": "string"
      "enum": ["active", "inactive", "disabled", "full", "standby"]
    }
  },
  "required": [ "QueueStateEventUri", "QueueStateEventQueueLength", "QueueStateEventMaxLength", "QueueStateValuesCode" ]
}
```

## AbandonedCall
```json
{
  "$schema": "http://json-schema.org/draft-07/schema#",
  "$id": "https://forge.etsi.org/rep/emtel/ts-103-479/json-schema/",
  "title": "AbandonedCall",
  "description": "AbandonedCall event notification",
  "type": "object",
  "properties": {
    "Invite": {
      "description": "Content of INVITE message",
      "type": "string"
    },
    "InviteTimestamp": {
      "description": "Timestamp call was received at ESRP",
      "type": "string"
    },
    "CancelTimestamp": {
      "description": "Timestamp CANCEL was received at ESRP",
      "type": "string"
    }
  },
  "required": [ "Invite", "InviteTimestamp", "CancelTimestamp" ]
}
```

## SecurityPosture
```json
{
  "$schema": "http://json-schema.org/draft-07/schema#",
  "$id": "https://forge.etsi.org/rep/emtel/ts-103-479/json-schema/",
  "title": "SecurityPosture",
  "description": "SecurityPosture event notification",
  "type": "object",
  "properties": {
    "Posture": {
      "description": "Enumeration of current security posture",
      "type": "string"
      "enum": ["green", "yellow", "orange", "red"]
    }
  },
  "required": [ "Posture" ]
}
```

##	ElementState
```json
{
  "$schema": "http://json-schema.org/draft-07/schema#",
  "$id": "https://forge.etsi.org/rep/emtel/ts-103-479/json-schema/",
  "title": "ElementState",
  "description": "ElementState event notification",
  "type": "object",
  "properties": {
    "State": {
      "description": "Enumeration of current element state",
      "type": "string"
      "enum": ["normal", "sheduledMaintenance", "serviceDisruption", "overloaded", "goingDown", "down"]
    },
    "Reason": {
      "description": "Text containing the reason state was changed, if available",
      "type": "string"
    }
  },
  "required": [ "State" ]
}
```

##	ServiceState
```json
{
  "$schema": "http://json-schema.org/draft-07/schema#",
  "$id": "https://forge.etsi.org/rep/emtel/ts-103-479/json-schema/",
  "title": "ServiceState",
  "description": "ServiceState event notification",
  "type": "object",
  "properties": {
    "Service": {
      "description": "Name of the service",
      "type": "string"
    },
    "State": {
      "description": "Enumeration of current service state",
      "type": "string"
      "enum": ["normal", "unmanned", "sheduledMaintenance(down)", "sheduledMaintenance(available)", "majorIncidentInProgress", "partialService", "overloaded", "goingDown", "down"]
    },
    "Reason": {
      "description": "Text containing the reason state was changed, if available",
      "type": "string"
    }
  },
  "required": [ "Service", "State" ]
}
```
